/**
 * This file is part of Haketilo.
 *
 * Function: Expose some special functionalities to injected scripts using
 *           CustomEvent's to communicate with them.
 *
 * Copyright (C) 2022 Wojtek Kosior
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * As additional permission under GNU GPL version 3 section 7, you
 * may distribute forms of that code without the copy of the GNU
 * GPL normally required by section 4, provided you include this
 * license notice and, in case of non-source distribution, a URL
 * through which recipients can access the Corresponding Source.
 * If you modify file(s) with this exception, you may extend this
 * exception to your version of the file(s), but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * As a special exception to the GPL, any HTML file which merely
 * makes function calls to this code, and for that purpose
 * includes it by reference shall be deemed a separate work for
 * copyright law purposes. If you modify this code, you may extend
 * this exception to your version of the code, but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * I, Wojtek Kosior, thereby promise not to sue for violation of this file's
 * license. Although I request that you do not make use of this code in a
 * proprietary program, I am not going to enforce this in court.
 */

#FROM common/browser.js IMPORT browser
#FROM common/misc.js    IMPORT error_data_jsonifiable

async function on_CORS_bypass(event) {
    const name = "haketilo_CORS_bypass";

    if (typeof event.detail      !== "object" ||
	event.detail             === null     ||
	typeof event.detail.id   !== "string" ||
	typeof event.detail.data !== "string") {
	console.error(`Haketilo: Invalid detail for ${name}:`,
		      event.detail);
	return;
    }

    try {
	const data = JSON.parse(event.detail.data);
	var result = await browser.runtime.sendMessage(["CORS_bypass", data]);
	if (result === undefined)
	    throw new Error("Couldn't communicate with Haketilo background script.");
    } catch(e) {
	var result = {error: error_data_jsonifiable(e)};
    }

    const response_name = `${name}-${event.detail.id}`;
    const detail = JSON.stringify(result);
    window.dispatchEvent(new CustomEvent(response_name, {detail}));
}

function start() {
    window.addEventListener("haketilo_CORS_bypass", on_CORS_bypass);
}
#EXPORT start
